@@ -23,12 +23,15 @@ class LoginRequiredMiddleware(MiddlewareMixin):
     def __init__(self, *args, **kwargs):
         if MiddlewareMixin != object:
             super(LoginRequiredMiddleware, self).__init__(*args, **kwargs)
-        self.public_view_urls = getattr(conf, 'STRONGHOLD_PUBLIC_URLS', ())
+        self.public_view_urls = getattr(conf, "STRONGHOLD_PUBLIC_URLS", ())
 
     def process_view(self, request, view_func, view_args, view_kwargs):
-        if conf.STRONGHOLD_USER_TEST_FUNC(request.user) \
-                or utils.is_view_func_public(view_func) \
-                or self.is_public_url(request.path_info):
+        if (
+            utils.is_view_func_public(view_func)
+            or self.is_public_url(request.path_info)
+            or conf.STRONGHOLD_USER_TEST_FUNC(request.user)
+            and conf.STRONGHOLD_REQUEST_TEST_FUNC(request, view_func, view_args, view_kwargs)
+        ):
             return None
 
         decorator = user_passes_test(conf.STRONGHOLD_USER_TEST_FUNC)
