@@ -7,6 +7,7 @@ if django.VERSION[:2] < (1, 9):
     from django.utils import unittest
 else:
     import unittest
+from django.utils.decorators import method_decorator
 
 
 class StrongholdDecoratorTests(unittest.TestCase):
@@ -37,3 +38,11 @@ class StrongholdDecoratorTests(unittest.TestCase):
         decorators.public(partial)
 
         self.assertTrue(function.STRONGHOLD_IS_PUBLIC)
+
+    def test_public_decorator_works_with_method_decorator(self):
+        class TestClass:
+            @method_decorator(decorators.public)
+            def function(self):
+                pass
+
+        self.assertTrue(TestClass.function.STRONGHOLD_IS_PUBLIC)
\ No newline at end of file
