@@ -1,6 +1,10 @@
 from stronghold import utils
 
-from django.utils import unittest
+import django
+if django.VERSION[:2] < (1, 9):
+    from django.utils import unittest
+else:
+    import unittest
 
 
 class IsViewFuncPublicTests(unittest.TestCase):
